<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Export\Filter\AccompanyingCourseFilters;

use Chill\MainBundle\Export\FilterInterface;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Chill\PersonBundle\Entity\SocialWork\SocialAction;
use Chill\PersonBundle\Export\Declarations;
use Chill\PersonBundle\Form\Type\PickSocialActionType;
use Chill\PersonBundle\Templating\Entity\SocialActionRender;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Form\FormBuilderInterface;

final readonly class SocialActionFilter implements FilterInterface
{
    public function __construct(private SocialActionRender $actionRender) {}

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $qb->andWhere(
            $qb->expr()->exists(
                sprintf(
                    'SELECT 1 FROM %s acp_by_social_action_filter WHERE acp_by_social_action_filter.socialAction '
                    .'IN (:acp_by_social_action_filter_actions) AND acp_by_social_action_filter.accompanyingPeriod = acp',
                    AccompanyingPeriod\AccompanyingPeriodWork::class
                )
            )
        );

        $qb->setParameter('acp_by_social_action_filter_actions', SocialAction::getDescendantsWithThisForActions($data['accepted_socialactions']));
    }

    public function applyOn(): string
    {
        return Declarations::ACP_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('accepted_socialactions', PickSocialActionType::class, [
            'multiple' => true,
        ]);
    }

    public function getFormDefaultData(): array
    {
        return [];
    }

    public function describeAction($data, $format = 'string'): array
    {
        $actions = [];

        $socialactions = $data['accepted_socialactions'];

        foreach ($socialactions as $action) {
            $actions[] = $this->actionRender->renderString($action, [
                'show_and_children' => true,
            ]);
        }

        return ['Filtered by socialactions: only %socialactions%', [
            '%socialactions%' => implode(', ', $actions),
        ]];
    }

    public function getTitle(): string
    {
        return 'Filter by socialaction';
    }
}
